This function obtains the information about of an eLTER
dataset (e.g.
https://deims.org/dataset/38d604ef-decb-4d67-8ac3-cc843d10d3ef)
provided in DEIMS-SDR catalogue.
Arguments
- datasetid
A
character. It is the DEIMS ID of dataset make from DEIMS-SDR website. DEIMS ID information here. The DEIMS ID of dataset is the URL for the dataset page.- show_map
A
boolean. If TRUE a Leaflet map with occurrences is shown. Default FALSE.
Value
The output of the function is a list with two elements:
mapA Leaflet map with the dataset location, if requested withshow_map.dataAdata.framewith the information about the dataset.
Author
Alessandro Oggioni, phD (2020) oggioni.a@irea.cnr.it