Obtain the information about of an eLTER location.
Source:R/get_location_info.R
get_location_info_internal.Rd
This function obtains the information about of an eLTER
location (e.g.
https://deims.org/location/12b38f3f-7e72-425a-80c7-7cad35ce4c7b)
provided in DEIMS-SDR catalogue.
Arguments
- locationid
A
character. It is the DEIMS ID of location make from DEIMS-SDR website. DEIMS ID information here. The DEIMS.iD of activity is the URL for the location page.- show_map
A
boolean. If TRUE a Leaflet map with occurrences is shown. Default FALSE.
Value
The output of the function is a list with two elements:
mapA Leaflet map with the location, if requested withshow_map.dataAdata.framewith the information about the location.
Author
Alessandro Oggioni, phD (2020) oggioni.a@irea.cnr.it
Paolo Tagliolato, phD tagliolato.p@irea.cnr.it